@@ -65,7 +65,7 @@ class TestMultiFileLayout(tests.TestCase):
 			self.assertEqual(layout.page_file(path), file)
 			self.assertEqual(layout.attachments_dir(path), adir)
 
-		self.assertRaises(PathLookupError, layout.page_file, Path(':'))
+		self.assertRaises(ValueError, layout.page_file, Path(':'))
 
 
 		layout = MultiFileLayout(dir, 'html', namespace=Path('Test'))
@@ -79,8 +79,8 @@ class TestMultiFileLayout(tests.TestCase):
 			self.assertEqual(layout.page_file(path), file)
 			self.assertEqual(layout.attachments_dir(path), adir)
 
-		self.assertRaises(PathLookupError, layout.page_file, Path(':'))
-		self.assertRaises(PathLookupError, layout.page_file, Path('Foo'))
+		self.assertRaises(ValueError, layout.page_file, Path(':'))
+		self.assertRaises(ValueError, layout.page_file, Path('Foo'))
 
 
 class TestFileLayout(tests.TestCase):
@@ -110,8 +110,8 @@ class TestFileLayout(tests.TestCase):
 			self.assertEqual(layout.page_file(path), file)
 			self.assertEqual(layout.attachments_dir(path), adir)
 
-		self.assertRaises(PathLookupError, layout.page_file, Path(':'))
-		self.assertRaises(PathLookupError, layout.page_file, Path('Foo'))
+		self.assertRaises(ValueError, layout.page_file, Path(':'))
+		self.assertRaises(ValueError, layout.page_file, Path('Foo'))
 
 
 class TestSingleFileLayout(tests.TestCase):
@@ -140,8 +140,8 @@ class TestSingleFileLayout(tests.TestCase):
 			self.assertEqual(layout.page_file(path), file)
 			self.assertEqual(layout.attachments_dir(path), adir)
 
-		self.assertRaises(PathLookupError, layout.page_file, Path(':'))
-		self.assertRaises(PathLookupError, layout.page_file, Path('Foo'))
+		self.assertRaises(ValueError, layout.page_file, Path(':'))
+		self.assertRaises(ValueError, layout.page_file, Path('Foo'))
 
 
 
@@ -149,9 +149,9 @@ class TestLinker(tests.TestCase):
 
 	def runTest(self):
 		notebook = self.setUpNotebook(content=('foo', 'bar', 'foo:bar',))
-		dir = Dir(notebook.folder.parent().folder('layout').path)
+		folder = self.setUpFolder('layout')
 
-		layout = MultiFileLayout(dir.subdir('layout'), 'html')
+		layout = MultiFileLayout(folder, 'html')
 		source = Path('foo:bar')
 		output = layout.page_file(source)
 
@@ -324,6 +324,31 @@ class TestExportTemplateContext(tests.TestCase):
 
 
 
+class TestPageProxyWithFormattedHeading(tests.TestCase):
+
+	CONTENT = {
+		'test': '''\
+======= This is a **heading** with __formatting__ =======
+
+Some content here
+'''
+	}
+
+	def runTest(self):
+		from zim.formats import StubLinker
+		notebook = self.setUpNotebook(content=self.CONTENT)
+		page = notebook.get_page(Path('test'))
+		dumper = get_format('html').Dumper()
+		linker = StubLinker()
+		proxy = PageProxy(notebook, page, dumper, linker)
+
+		self.assertEqual(proxy.title, 'This is a heading with formatting')
+		self.assertEqual(proxy.heading, 'This is a <b>heading</b> with <u>formatting</u>')
+		self.assertIsInstance(proxy.body, str)
+		self.assertTrue(proxy.body.startswith('<p>'))
+		self.assertIsInstance(proxy.content, str)
+		self.assertTrue(proxy.content.startswith('<h1>'))
+
 
 class TestPageSelections(tests.TestCase):
 
@@ -434,9 +459,8 @@ class TestExportFormat(object):
 		notebook = self.setUpNotebook(content=tests.FULL_NOTEBOOK)
 
 		i = 0
-		print('')
 		for template, file in list_templates(self.format):
-			#print 'Testing template: %s' % template
+			#print('Testing template: %s' % template)
 			pages = AllPages(notebook) # TODO - sub-section ?
 			exporter = build_notebook_exporter(output_folder.folder(template), self.format, template)
 			self.assertIsInstance(exporter, MultiFileExporter)
@@ -646,7 +670,7 @@ class TestExportDialog(tests.TestCase):
 
 		#~ print dialog.uistate
 		self.assertEqual(dialog.uistate, window.notebook.state['ExportDialog'])
-		self.assertIsInstance(dialog.uistate['output_folder'], Dir)
+		self.assertIsInstance(adapt_from_oldfs(dialog.uistate['output_folder']), Folder)
 
 		## Test export single page
 		dialog = ExportDialog(window, notebook, Path('foo'))
