@@ -8,27 +8,6 @@ from zim.parser import *
 
 class TestParsing(tests.TestCase):
 
-	def testSplitWords(self):
-		'''Test parsing quoted strings'''
-		string = r'''"foo bar", "\"foooo bar\"" dusss ja'''
-		list = ['foo bar', ',', '"foooo bar"', 'dusss', 'ja']
-		result = split_quoted_strings(string)
-		self.assertEqual(result, list)
-		list = ['"foo bar"', ',', r'"\"foooo bar\""', 'dusss', 'ja']
-		result = split_quoted_strings(string, unescape=False)
-		self.assertEqual(result, list)
-
-		string = r'''"foo bar", False, True'''
-		list = ['foo bar', ',', 'False', ',', 'True']
-		result = split_quoted_strings(string)
-		self.assertEqual(result, list)
-
-		self.assertRaises(ValueError, split_quoted_strings, "If you don't mind me asking")
-		string = "If you don't mind me asking"
-		list = ["If", "you", "don", "'t", "mind", "me", "asking"]
-		result = split_quoted_strings(string, strict=False)
-		self.assertEqual(result, list)
-
 	def testParseDate(self):
 		'''Test parsing dates'''
 		from datetime import date
@@ -273,14 +252,13 @@ class TestBuilderTextBuffer(tests.TestCase):
 
 class TestParser(tests.TestCase):
 
-	def testFunctions(self):
-		# Helper functions
-
-		self.assertEqual(fix_line_end('foo'), 'foo\n')
-		self.assertEqual(fix_line_end('foo\nbar'), 'foo\nbar\n')
+	def testFixUnicode(self):
+		self.assertEqual(fix_unicode_chars('foo\u2028bar\u2029check\n'), 'foo\nbar check\n')
 
+	def testConvertSpaceToTab(self):
 		self.assertEqual(convert_space_to_tab('    foo\n\t     bar\n'), '\tfoo\n\t\t bar\n')
 
+	def testGetLineCount(self):
 		text = 'foo\nbar\nbaz\n'
 		for offset, wanted in (
 			(0, (1, 0)),
