@@ -8,28 +8,29 @@ the freedesktop.org (XDG) Base Dir specification.
 import os
 import logging
 
-from zim.fs import File, Dir
+from zim.newfs import LocalFile, LocalFolder
 
 
 logger = logging.getLogger('zim.config')
 
 
 def _split_environ_dir_list(value, default=()):
-	if isinstance(value, str):
-		value = value.strip()
-
-	paths = value.split(os.pathsep) if value else default
-	return [Dir(p) for p in paths]
+	value = value.strip() if isinstance(value, str) else value
+	if value:
+		paths = value.split(os.pathsep)
+	else:
+		paths = default
+	return [LocalFolder(p) for p in paths]
 
 
 ## Initialize config paths
 
-ZIM_DATA_DIR = None #: 'data' dir relative to script file (when running from source), L{Dir} or C{None}
-XDG_DATA_HOME = None #: L{Dir} for XDG data home
-XDG_DATA_DIRS = None #: list of L{Dir} objects for XDG data dirs path
-XDG_CONFIG_HOME = None #: L{Dir} for XDG config home
-XDG_CONFIG_DIRS = None #: list of L{Dir} objects for XDG config dirs path
-XDG_CACHE_HOME = None #: L{Dir} for XDG cache home
+ZIM_DATA_DIR = None #: 'data' dir relative to script file (when running from source), L{LocalFolder} or C{None}
+XDG_DATA_HOME = None #: L{LocalFolder} for XDG data home
+XDG_DATA_DIRS = None #: list of L{LocalFolder} objects for XDG data dirs path
+XDG_CONFIG_HOME = None #: L{LocalFolder} for XDG config home
+XDG_CONFIG_DIRS = None #: list of L{LocalFolder} objects for XDG config dirs path
+XDG_CACHE_HOME = None #: L{LocalFolder} for XDG cache home
 
 def set_basedirs(_ignore_test=False):
 	'''This method sets the global configuration paths for according to the
@@ -46,48 +47,48 @@ def set_basedirs(_ignore_test=False):
 
 	# Cast string to folder
 	import zim
-	zim_data_dir = File(zim.ZIM_EXECUTABLE).dir.subdir('data')
+	zim_data_dir = LocalFile(zim.ZIM_EXECUTABLE).parent().folder('data')
 	if zim_data_dir.exists():
 		ZIM_DATA_DIR = zim_data_dir
 
 	if os.name == 'nt':
 		APPDATA = os.environ['APPDATA']
 
-		XDG_DATA_HOME = Dir(
-			os.environ.get('XDG_DATA_HOME', APPDATA + r'\zim\data'))
+		XDG_DATA_HOME = LocalFolder(
+			os.environ.get('XDG_DATA_HOME', APPDATA + r'\zim\data').strip())
 
 		XDG_DATA_DIRS = \
 			_split_environ_dir_list(os.environ.get('XDG_DATA_DIRS'), ('~/.local/share/',)) # Backwards compatibility
 
-		XDG_CONFIG_HOME = Dir(
-			os.environ.get('XDG_CONFIG_HOME', APPDATA + r'\zim\config'))
+		XDG_CONFIG_HOME = LocalFolder(
+			os.environ.get('XDG_CONFIG_HOME', APPDATA + r'\zim\config').strip())
 
 		XDG_CONFIG_DIRS = \
 			_split_environ_dir_list(os.environ.get('XDG_CONFIG_DIRS'), ('~/.config/',)) # Backwards compatibility
 
-		XDG_CACHE_HOME = Dir(
-			os.environ.get('XDG_CACHE_HOME', APPDATA + r'\zim\cache'))
+		XDG_CACHE_HOME = LocalFolder(
+			os.environ.get('XDG_CACHE_HOME', APPDATA + r'\zim\cache').strip())
 	else:
-		XDG_DATA_HOME = Dir(
-			os.environ.get('XDG_DATA_HOME', '~/.local/share/'))
+		XDG_DATA_HOME = LocalFolder(
+			os.environ.get('XDG_DATA_HOME', '~/.local/share/').strip())
 
 		XDG_DATA_DIRS = \
 			_split_environ_dir_list(os.environ.get('XDG_DATA_DIRS'), ('/usr/share/', '/usr/local/share/'))
 
-		XDG_CONFIG_HOME = Dir(
-			os.environ.get('XDG_CONFIG_HOME', '~/.config/'))
+		XDG_CONFIG_HOME = LocalFolder(
+			os.environ.get('XDG_CONFIG_HOME', '~/.config/').strip())
 
 		XDG_CONFIG_DIRS = \
 			_split_environ_dir_list(os.environ.get('XDG_CONFIG_DIRS'), ('/etc/xdg/',))
 
-		XDG_CACHE_HOME = Dir(
-			os.environ.get('XDG_CACHE_HOME', '~/.cache'))
+		XDG_CACHE_HOME = LocalFolder(
+			os.environ.get('XDG_CACHE_HOME', '~/.cache').strip())
 
 		if os.environ.get('ZIM_TEST_RUNNING') and not _ignore_test:
 			# See tests/__init__.py, we load more folders then we really want
 			# because the needs of Gtk, but want to restrict it here for all
 			# zim internal use
-			XDG_DATA_DIRS = [Dir(os.environ['TEST_XDG_DATA_DIRS'])]
+			XDG_DATA_DIRS = [LocalFolder(os.environ['TEST_XDG_DATA_DIRS'])]
 
 # Call on module initialization to set defaults
 set_basedirs()
@@ -98,7 +99,7 @@ def log_basedirs():
 	debug output
 	'''
 	if ZIM_DATA_DIR:
-		logger.debug('Running from a source dir: %s', ZIM_DATA_DIR.dir)
+		logger.debug('Running from a source dir: %s', ZIM_DATA_DIR.parent())
 	else:
 		logger.debug('Not running from a source dir')
 	logger.debug('Set XDG_DATA_HOME to %s', XDG_DATA_HOME)
