@@ -30,16 +30,11 @@ import types
 import ast
 import json
 
-try:
-	import collections.abc as abc
-except ImportError:
-	# python < version 3.3
-	import collections as abc
+import collections.abc as abc
 
 from zim.signals import SignalEmitter, ConnectorMixin, SIGNAL_NORMAL, init_signals_for_new_object
 from zim.utils import DefinitionOrderedDict
-from zim.fs import File, FileNotFoundError
-from zim.newfs import FileNotFoundError as NewFileNotFoundError
+from zim.newfs import FileNotFoundError
 from zim.errors import Error
 
 from .basedirs import XDG_CONFIG_HOME
@@ -79,6 +74,13 @@ class ControlledDict(DefinitionOrderedDict, SignalEmitter, ConnectorMixin):
 			self.disconnect_from(v)
 		self.emit('changed')
 
+	def pop(self, key, default=None):
+		# Only emit changed once here
+		with self.block_signals('changed'):
+			v = DefinitionOrderedDict.pop(self, key, default)
+		self.emit('changed')
+		return v
+
 	def update(self, E=(), **F):
 		# Only emit changed once here
 		with self.block_signals('changed'):
@@ -244,7 +246,13 @@ class Boolean(ConfigDefinition):
 class String(ConfigDefinition):
 	'''This class defines a config key that maps to a string'''
 
-	# TODO support esacpe codes \s \t \n \r (see desktop / json spec)
+	# Might expect backslash escaping to be supported here
+	# however we cannot add that backward compatible because this
+	# config type is also used to store paths which may contain
+	# windows paths with unescaped backslashes.
+	# If e.g. a multiline value with escaped "\n" is needed, this
+	# requires a separate "MultiLineString" class or similar.
+	# See also the String definition used in zim.gui.applications
 
 	def __init__(self, default, allow_empty=False):
 		if default == '':
@@ -491,7 +499,7 @@ class ConfigDict(ControlledDict):
 		new._input.update(self._input)
 		return new
 
-	def update(self, E=None, **F):
+	def update(self, E=(), **F):
 		'''Like C{dict.update()}, copying values from C{E} or C{F}.
 		However if C{E} is also a C{ConfigDict}, also the definitions
 		are copied along.
@@ -741,7 +749,7 @@ class INIConfigFile(SectionedConfigDict):
 			with self.block_signals('changed'):
 				self.read()
 			self.set_modified(False)
-		except (FileNotFoundError, NewFileNotFoundError):
+		except FileNotFoundError:
 			pass
 
 		if monitor:
@@ -752,7 +760,7 @@ class INIConfigFile(SectionedConfigDict):
 			try:
 				with self.block_signals('changed'):
 					self.read()
-			except (FileNotFoundError, NewFileNotFoundError):
+			except FileNotFoundError:
 				pass
 			else:
 				# First emit top level to allow general changes
