@@ -1,9 +1,11 @@
-# -*- coding: utf-8 -*-
 
 # Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
-from zim.plugins.base.imagegenerator import ImageGeneratorPlugin, ImageGeneratorClass
-from zim.fs import File, TmpFile
+from zim.plugins import PluginClass
+from zim.plugins.base.imagegenerator import \
+	ImageGeneratorClass, BackwardImageGeneratorObjectType
+
+from zim.newfs import LocalFile, TmpFile
 from zim.config import data_file
 from zim.applications import Application, ApplicationError
 
@@ -12,7 +14,7 @@ from zim.applications import Application, ApplicationError
 dotcmd = ('dot', '-Tpng', '-o')
 
 
-class InsertDiagramPlugin(ImageGeneratorPlugin):
+class InsertDiagramPlugin(PluginClass):
 
 	plugin_info = {
 		'name': _('Insert Diagram'), # T: plugin name
@@ -25,36 +27,33 @@ This is a core plugin shipping with zim.
 		'author': 'Jaap Karssenberg',
 	}
 
-	object_type = 'diagram'
-	short_label = _('Dia_gram...') # T: menu item
-	insert_label = _('Insert diagram') # T: menu item
-	edit_label = _('_Edit diagram') # T: menu item
-	syntax = 'dot'
-
 	@classmethod
 	def check_dependencies(klass):
 		has_dotcmd = Application(dotcmd).tryexec()
 		return has_dotcmd, [("GraphViz", has_dotcmd, True)]
 
 
+class BackwardDiagramImageObjectType(BackwardImageGeneratorObjectType):
+
+	name = 'image+diagram'
+	label = _('Diagram') # T: menu item
+	syntax = 'dot'
+	scriptname = 'diagram.dot'
+
+
 class DiagramGenerator(ImageGeneratorClass):
 
-	uses_log_file = False
+	imagefile_extension = '.png'
 
-	object_type = 'diagram'
-	scriptname = 'diagram.dot'
-	imagename = 'diagram.png'
-
-	def __init__(self, plugin):
-		ImageGeneratorClass.__init__(self, plugin)
-		self.dotfile = TmpFile(self.scriptname)
+	def __init__(self, plugin, notebook, page):
+		ImageGeneratorClass.__init__(self, plugin, notebook, page)
+		self.dotfile = TmpFile('diagram.dot')
 		self.dotfile.touch()
-		self.pngfile = File(self.dotfile.path[:-4] + '.png') # len('.dot') == 4
+		self.pngfile = LocalFile(self.dotfile.path[:-4] + '.png') # len('.dot') == 4
 
 	def generate_image(self, text):
-
 		# Write to tmp file
-		self.dotfile.writelines(text)
+		self.dotfile.write(text)
 
 		# Call GraphViz
 		try:
