@@ -1,6 +1,6 @@
 
-# Copyright 2010 Fabian Moser
-# Copyright 2011-2017 Jaap Karssenberg
+# Copyright 2010 Fabian Stanke
+# Copyright 2011-2021 Jaap Karssenberg
 
 
 from gi.repository import GObject
@@ -22,10 +22,9 @@ from zim.notebook.index.tags import IS_PAGE, IS_TAG, \
 	TagsView, TaggedPagesTreeModelMixin, TagsTreeModelMixin, IndexTag
 from zim.utils import natural_sort_key
 
-from zim.gui.pageview import PageViewExtension
+from zim.gui.notebookview import NotebookViewExtension
 from zim.gui.widgets import LEFT_PANE, PANE_POSITIONS, populate_popup_add_separator, ScrolledWindow, encode_markup_text, \
 	WindowSidePaneWidget
-from zim.gui.clipboard import pack_urilist, INTERNAL_PAGELIST_TARGET_NAME
 
 
 logger = logging.getLogger('zim.plugins.tags')
@@ -39,7 +38,7 @@ class TagsPlugin(PluginClass):
 		'description': _('''\
 This plugin provides a page index filtered by means of selecting tags in a cloud.
 '''), # T: plugin description
-		'author': 'Fabian Moser & Jaap Karssenberg',
+		'author': 'Fabian Stanke & Jaap Karssenberg',
 		'help': 'Plugins:Tags',
 	}
 
@@ -47,13 +46,21 @@ This plugin provides a page index filtered by means of selecting tags in a cloud
 		# key, type, label, default
 		('pane', 'choice', _('Position in the window'), LEFT_PANE, PANE_POSITIONS),
 			# T: option for plugin preferences
+		('autoexpand', 'bool', _('Automatically expand sections on open page'), True),
+			# T: preferences option
+		('autocollapse', 'bool', _('Automatically collapse sections on close page'), True),
+			# T: preferences option
+		('use_hscroll', 'bool', _('Use horizontal scrollbar (may need restart)'), False),
+			# T: preferences option
+		('use_tooltip', 'bool', _('Use tooltips'), True),
+			# T: preferences option
 	)
 
 
-class TagsPageViewExtension(PageViewExtension):
+class TagsNotebookViewExtension(NotebookViewExtension):
 
 	def __init__(self, plugin, pageview):
-		PageViewExtension.__init__(self, plugin, pageview)
+		NotebookViewExtension.__init__(self, plugin, pageview)
 
 		self.widget = TagsPluginWidget(
 			pageview.notebook,
@@ -75,11 +82,20 @@ class TagsPageViewExtension(PageViewExtension):
 		#))
 		self.connectto(pageview, 'page-changed', lambda o, p: self.widget.set_page(p))
 
+		self.on_preferences_changed(self.plugin.preferences)
+		self.plugin.preferences.connect('changed', self.on_preferences_changed)
+
+	def on_preferences_changed(self, preferences):
+		self.widget.treeview.set_use_tooltip(preferences['use_tooltip'])
+		self.widget.treeview.set_use_ellipsize(not preferences['use_hscroll'])
+			# To use horizontal scrolling, turn off ellipsize
+		self.widget.treeview.set_autoexpand(preferences['autoexpand'], preferences['autocollapse'])
+
 
 class TagsPluginWidget(Gtk.VPaned, WindowSidePaneWidget):
 	'''Widget combining a tag cloud and a tag based page treeview'''
 
-	title = _('Tags') # T: title for sidepane tab
+	title = _('T_ags') # T: title for sidepane tab
 
 	def __init__(self, notebook, navigation, uistate):
 		GObject.GObject.__init__(self)
@@ -169,8 +185,9 @@ class TagsPluginWidget(Gtk.VPaned, WindowSidePaneWidget):
 		without need to close the app first.
 		'''
 		assert self.uistate['treeview'] in ('tagged', 'tags')
-		tags = [t.name for t in self.tagcloud.get_tag_filter()]
+		self.treeview.disconnect_index()
 
+		tags = [t.name for t in self.tagcloud.get_tag_filter()]
 		if tags:
 			model = TaggedPageTreeStore(self.index, tags, self.uistate['show_full_page_name'])
 		elif self.uistate['treeview'] == 'tags':
@@ -180,6 +197,12 @@ class TagsPluginWidget(Gtk.VPaned, WindowSidePaneWidget):
 
 		self.treeview.set_model(model)
 
+		def handler(o, *a):
+			signal = a[-1]
+			path = a[0].to_string()
+		for signal in ('row-inserted', 'row-changed', 'row-deleted', 'row-has-child-toggled'):
+			model.connect(signal, handler, signal)
+
 
 class DuplicatePageTreeStore(PageTreeStoreBase):
 	'''Sub-class of PageTreeStore that allows for the same page appearing
@@ -273,18 +296,6 @@ class TaggedPageTreeStore(TaggedPagesTreeModelMixin, DuplicatePageTreeStore):
 
 class TagsPageTreeView(PageTreeView):
 
-	def do_drag_data_get(self, dragcontext, selectiondata, info, time):
-		assert selectiondata.get_target().name() == INTERNAL_PAGELIST_TARGET_NAME
-		model, iter = self.get_selection().get_selected()
-		path = model.get_indexpath(iter)
-		if isinstance(path, IndexTag):
-			link = '@' + path.name
-		else:
-			link = path.name
-		logger.debug('Drag data requested, we have internal tag/path "%s"', link)
-		data = pack_urilist((link,))
-		selectiondata.set(selectiondata.get_target(), 8, data)
-
 	def set_current_page(self, path, vivificate=False):
 		'''Set the current page in the treeview
 
